@@ -21,7 +21,6 @@ EVT_CALL_MISS="""RTCOM_EL_EVENTTYPE_CALL_MISSED"""
 EVT_CALL_VOICEMAIL="""RTCOM_EL_EVENTTYPE_CALL_VOICEMAIL"""
 CONFIG_DIR="/home/user/.smscounter"
 CONFIG_FILE=CONFIG_DIR+"/options.cfg"
-
 def getSQL(sqlstr):
     #print sqlstr
     #sql=pexpect.spawn("sqlite3",[DB_FILE,sqlstr])
@@ -112,6 +111,12 @@ def timeFormat(secs):
 class ConfigData(object):
     sms_cost=0
     call_minute_cost=0
+    from_date=""
+    to_date=""
+    widget_period=1
+    widget_showSMS=True
+    widget_showCalls=True
+    log="Nada"
 
     @staticmethod
     def save():
@@ -119,7 +124,13 @@ class ConfigData(object):
             os.makedirs(CONFIG_DIR)
         f=open(CONFIG_FILE,"w")
         f.write("SMSCost="+str(ConfigData.sms_cost)+"\n")
-        f.write("CallCost="+str(ConfigData.call_minute_cost))
+        f.write("CallCost="+str(ConfigData.call_minute_cost)+"\n")
+        f.write("from_date="+str(ConfigData.from_date)+"\n")
+        f.write("to_date="+str(ConfigData.to_date)+"\n")
+        f.write("widget_period="+str(ConfigData.widget_period)+"\n")
+        f.write("widget_showSMS="+str(ConfigData.widget_showSMS)+"\n")
+        f.write("widget_showCalls="+str(ConfigData.widget_showCalls))
+        
     @staticmethod
     def load():
         if os.path.exists(CONFIG_FILE):
@@ -134,7 +145,18 @@ class ConfigData(object):
                             ConfigData.sms_cost=float(line[1])
                         elif line[0]=="CallCost":
                             ConfigData.call_minute_cost=float(line[1])
-                    except ex:
+                        elif line[0]=="from_date":
+                            ConfigData.from_date=str(line[1]).replace("\n","")
+                        elif line[0]=="to_date":
+                            ConfigData.to_date=str(line[1]).replace("\n","")
+                        elif line[0]=="widget_period":
+                            ConfigData.widget_period=int(line[1])
+                        elif line[0]=="widget_showSMS":
+                            ConfigData.widget_showSMS=(str(line[1]).replace("\n","")=='True')
+                        elif line[0]=="widget_showCalls":
+                            ConfigData.widget_showCalls=(str(line[1]).replace("\n","")=='True')
+                        
+                    except Exception, ex:
                         print ex
                         
 class About(object):
@@ -158,7 +180,7 @@ class About(object):
 "p, li { white-space: pre-wrap; }\n"
 "</style></head><body style=\" font-family:\'Ubuntu\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
 "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:16pt; font-weight:600;\">SMS Counter</span></p>\n"
-"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt; font-weight:600;\">v0.4</span></p>\n"
+"<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt; font-weight:600;\">v0.5</span></p>\n"
 "<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt; font-weight:600;\"></p>\n"
 "<p align=\"center\" style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><img src=\"/usr/share/icons/hicolor/64x64/hildon/smscounter.png\" /></p>\n"
 "<p align=\"center\" style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt; font-weight:600;\"></p>\n"
@@ -342,7 +364,29 @@ class MainWidget(object):
         QtCore.QObject.connect(self.btnGo, QtCore.SIGNAL("clicked()"), self.btnGoAction)
         QtCore.QObject.connect(self.chkFrom, QtCore.SIGNAL("stateChanged(int)"), self.chkFromSelected)
         QtCore.QObject.connect(self.chkTo, QtCore.SIGNAL("stateChanged(int)"), self.chkToSelected)
-        
+        self.load()
+
+    def save(self):
+	s=""
+	if self.chkFrom.checkState():
+	    s=str(self.fromDate.currentDate().toString("dd.MM.yyyy"))
+	ConfigData.from_date=s
+	s=""
+	if self.chkTo.checkState():
+	    s=str(self.toDate.currentDate().toString("dd.MM.yyyy"))
+	ConfigData.to_date=s
+        ConfigData.save()
+    
+    def initDatePicker(self,datePicker,chk,strDate):
+	if strDate:
+	    date=QtCore.QDate.fromString(strDate,"dd.MM.yyyy")
+	    datePicker.setCurrentDate(date)
+	    chk.setChecked(True)
+	
+    def load(self):
+	self.initDatePicker(self.fromDate,self.chkFrom,ConfigData.from_date)
+	self.initDatePicker(self.toDate,self.chkTo,ConfigData.to_date)
+	
     def retranslateUi(self, Form):
         Form.setWindowTitle(QtGui.QApplication.translate("Form", "SMS Counter", None, QtGui.QApplication.UnicodeUTF8))
         self.btnFrom.setText("From")
@@ -621,6 +665,9 @@ class Main(QtGui.QWidget):
         QtGui.QWidget.__init__(self, parent)
         self.mw=MainWidget()
         self.mw.setupUi(self)
+    def closeEvent(self,closeEvent):
+	self.mw.save()
+	QtGui.QWidget.closeEvent(self,closeEvent)
 def main():
     locale.setlocale(locale.LC_ALL, '')
     app = QtGui.QApplication(sys.argv)
